@@ -12,7 +12,7 @@ use Mo::utils::CSS 0.07 qw(check_css_class check_css_unit);
 use Scalar::Util qw(blessed);
 use Unicode::UTF8 qw(decode_utf8);
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -684,6 +684,86 @@ Returns undef.
 
 =end html
 
+=head1 EXAMPLE4
+
+=for comment filename=plack_app_tree_color.pl
+
+ use strict;
+ use warnings;
+ 
+ use CSS::Struct::Output::Indent;
+ use Plack::App::Tags::HTML;
+ use Plack::Runner;
+ use Tags::HTML::Tree;
+ use Tags::Output::Indent;
+ use Tree;
+
+ # Example tree object.
+ my $data_tree = Tree->new('Root');
+ $data_tree->meta({'color' => 'orange'});
+ my %node;
+ foreach my $node_string (qw/H I J K L M N O P Q/) {
+          $node{$node_string} = Tree->new($node_string);
+ }
+ $data_tree->add_child($node{'H'});
+ $node{'H'}->meta({'color' => 'red'});
+ $node{'H'}->add_child($node{'I'});
+ $node{'I'}->add_child($node{'J'});
+ $node{'J'}->meta({'color' => 'green'});
+ $node{'H'}->add_child($node{'K'});
+ $node{'H'}->add_child($node{'L'});
+ $data_tree->add_child($node{'M'});
+ $data_tree->add_child($node{'N'});
+ $node{'N'}->add_child($node{'O'});
+ $node{'O'}->add_child($node{'P'});
+ $node{'O'}->meta({'color' => 'blue'});
+ $node{'P'}->add_child($node{'Q'});
+ 
+ my $css = CSS::Struct::Output::Indent->new;
+ my $tags = Tags::Output::Indent->new(
+         'xml' => 1,
+         'preserved' => ['script', 'style'],
+ );
+ my $app = Plack::App::Tags::HTML->new(
+         'component' => 'Tags::HTML::Tree',
+         'constructor_args' => {
+                 'cb_value' => sub {
+                         my ($self, $tree) = @_;
+
+                         if (exists $tree->meta->{'color'}) {
+                                 $self->{'tags'}->put(
+                                         ['b', 'span'],
+                                         ['a', 'style', 'color:'.$tree->meta->{'color'}.';'],
+                                 );
+                         }
+                         $self->{'tags'}->put(
+                                 ['d', $tree->value],
+                         );
+                         if (exists $tree->meta->{'color'}) {
+                                 $self->{'tags'}->put(
+                                         ['e', 'span'],
+                                 );
+                         }
+
+                         return;
+                 },
+         },
+         'data_init' => [$data_tree],
+         'css' => $css,
+         'tags' => $tags,
+ )->to_app;
+ Plack::Runner->new->run($app);
+
+ # Output screenshot is in images/ directory.
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Tree/master/images/plack_app_tree_color.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Tree/master/images/plack_app_tree_color.png" alt="Web app example" width="300px" height="300px" />
+</a>
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -713,6 +793,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
